@@ -11,35 +11,38 @@ const (
 
 // K9s tracks K9s configuration options.
 type K9s struct {
-	RefreshRate       int                 `yaml:"refreshRate"`
-	MaxConnRetry      int                 `yaml:"maxConnRetry"`
-	EnableMouse       bool                `yaml:"enableMouse"`
-	Headless          bool                `yaml:"headless"`
-	Logoless          bool                `yaml:"logoless"`
-	Crumbsless        bool                `yaml:"crumbsless"`
-	ReadOnly          bool                `yaml:"readOnly"`
-	NoIcons           bool                `yaml:"noIcons"`
-	Logger            *Logger             `yaml:"logger"`
-	CurrentContext    string              `yaml:"currentContext"`
-	CurrentCluster    string              `yaml:"currentCluster"`
-	Clusters          map[string]*Cluster `yaml:"clusters,omitempty"`
-	Thresholds        Threshold           `yaml:"thresholds"`
-	manualRefreshRate int
-	manualHeadless    *bool
-	manualLogoless    *bool
-	manualCrumbsless  *bool
-	manualReadOnly    *bool
-	manualCommand     *string
+	RefreshRate         int                 `yaml:"refreshRate"`
+	MaxConnRetry        int                 `yaml:"maxConnRetry"`
+	EnableMouse         bool                `yaml:"enableMouse"`
+	Headless            bool                `yaml:"headless"`
+	Logoless            bool                `yaml:"logoless"`
+	Crumbsless          bool                `yaml:"crumbsless"`
+	ReadOnly            bool                `yaml:"readOnly"`
+	NoIcons             bool                `yaml:"noIcons"`
+	Logger              *Logger             `yaml:"logger"`
+	CurrentContext      string              `yaml:"currentContext"`
+	CurrentCluster      string              `yaml:"currentCluster"`
+	Clusters            map[string]*Cluster `yaml:"clusters,omitempty"`
+	Thresholds          Threshold           `yaml:"thresholds"`
+	ScreenDumpDir       string              `yaml:"screenDumpDir"`
+	manualRefreshRate   int
+	manualHeadless      *bool
+	manualLogoless      *bool
+	manualCrumbsless    *bool
+	manualReadOnly      *bool
+	manualCommand       *string
+	manualScreenDumpDir *string
 }
 
 // NewK9s create a new K9s configuration.
 func NewK9s() *K9s {
 	return &K9s{
-		RefreshRate:  defaultRefreshRate,
-		MaxConnRetry: defaultMaxConnRetry,
-		Logger:       NewLogger(),
-		Clusters:     make(map[string]*Cluster),
-		Thresholds:   NewThreshold(),
+		RefreshRate:   defaultRefreshRate,
+		MaxConnRetry:  defaultMaxConnRetry,
+		Logger:        NewLogger(),
+		Clusters:      make(map[string]*Cluster),
+		Thresholds:    NewThreshold(),
+		ScreenDumpDir: K9sDefaultScreenDumpDir,
 	}
 }
 
@@ -91,6 +94,11 @@ func (k *K9s) OverrideCommand(cmd string) {
 	k.manualCommand = &cmd
 }
 
+// OverrideScreenDumpDir set the screen dump dir manually.
+func (k *K9s) OverrideScreenDumpDir(dir string) {
+	k.manualScreenDumpDir = &dir
+}
+
 // IsHeadless returns headless setting.
 func (k *K9s) IsHeadless() bool {
 	h := k.Headless
@@ -155,6 +163,20 @@ func (k *K9s) ActiveCluster() *Cluster {
 	return k.Clusters[k.CurrentCluster]
 }
 
+func (k *K9s) GetScreenDumpDir() string {
+	screenDumpDir := k.ScreenDumpDir
+
+	if k.manualScreenDumpDir != nil && *k.manualScreenDumpDir != "" {
+		screenDumpDir = *k.manualScreenDumpDir
+	}
+
+	if screenDumpDir == "" {
+		return K9sDefaultScreenDumpDir
+	}
+
+	return screenDumpDir
+}
+
 func (k *K9s) validateDefaults() {
 	if k.RefreshRate <= 0 {
 		k.RefreshRate = defaultRefreshRate
@@ -162,6 +184,9 @@ func (k *K9s) validateDefaults() {
 	if k.MaxConnRetry <= 0 {
 		k.MaxConnRetry = defaultMaxConnRetry
 	}
+	if k.ScreenDumpDir == "" {
+		k.ScreenDumpDir = K9sDefaultScreenDumpDir
+	}
 }
 
 func (k *K9s) validateClusters(c client.Connection, ks KubeSettings) {
