@@ -9,6 +9,7 @@ import (
 	"github.com/derailed/k9s/internal/health"
 	"github.com/derailed/k9s/internal/render"
 	"github.com/rs/zerolog/log"
+	metav1beta1 "k8s.io/apimachinery/pkg/apis/meta/v1beta1"
 	"k8s.io/apimachinery/pkg/runtime"
 )
 
@@ -98,7 +99,11 @@ func (h *PulseHealth) checkMetrics(ctx context.Context) (health.Checks, error) {
 func (h *PulseHealth) check(ctx context.Context, ns, gvr string) (*health.Check, error) {
 	meta, ok := Registry[gvr]
 	if !ok {
-		return nil, fmt.Errorf("No meta for %q", gvr)
+		meta = ResourceMeta{
+			DAO:      &dao.Table{},
+			Renderer: &render.Generic{},
+		}
+		// return nil, fmt.Errorf("No meta for %q", gvr)
 	}
 	if meta.DAO == nil {
 		meta.DAO = &dao.Resource{}
@@ -109,8 +114,29 @@ func (h *PulseHealth) check(ctx context.Context, ns, gvr string) (*health.Check,
 	if err != nil {
 		return nil, err
 	}
-
 	c := health.NewCheck(gvr)
+
+	if _, ok := meta.Renderer.(*render.Generic); ok {
+		table, ok := oo[0].(*metav1beta1.Table)
+		if !ok {
+			return nil, fmt.Errorf("expecting a meta table but got %T", oo[0])
+		}
+		rows := make(render.Rows, len(table.Rows))
+		gr, _ := meta.Renderer.(*render.Generic)
+		gr.SetTable(table)
+		for i, row := range table.Rows {
+			if err := gr.Render(row, ns, &rows[i]); err != nil {
+				return nil, err
+			}
+			if !render.Happy(ns, gr.Header(ns), rows[i]) {
+				c.Inc(health.S2)
+				continue
+			}
+			c.Inc(health.S1)
+		}
+		c.Total(int64(len(table.Rows)))
+		return c, nil
+	}
 	c.Total(int64(len(oo)))
 	rr, re := make(render.Rows, len(oo)), meta.Renderer
 	for i, o := range oo {
@@ -119,9 +145,9 @@ func (h *PulseHealth) check(ctx context.Context, ns, gvr string) (*health.Check,
 		}
 		if !render.Happy(ns, re.Header(ns), rr[i]) {
 			c.Inc(health.S2)
-		} else {
-			c.Inc(health.S1)
+			continue
 		}
+		c.Inc(health.S1)
 	}
 
 	return c, nil
