@@ -19,7 +19,7 @@ func NewEvent(gvr client.GVR) ResourceViewer {
 	}
 	e.GetTable().SetColorerFn(render.Event{}.ColorerFunc())
 	e.AddBindKeysFn(e.bindKeys)
-	e.GetTable().SetSortCol(ageCol, true)
+	e.GetTable().SetSortCol("LAST SEEN", false)
 
 	return &e
 }
@@ -27,9 +27,10 @@ func NewEvent(gvr client.GVR) ResourceViewer {
 func (e *Event) bindKeys(aa ui.KeyActions) {
 	aa.Delete(tcell.KeyCtrlD, ui.KeyE)
 	aa.Add(ui.KeyActions{
-		ui.KeyShiftY: ui.NewKeyAction("Sort Type", e.GetTable().SortColCmd("TYPE", true), false),
+		ui.KeyShiftL: ui.NewKeyAction("Sort LastSeen", e.GetTable().SortColCmd("LAST SEEN", false), false),
+		ui.KeyShiftT: ui.NewKeyAction("Sort Type", e.GetTable().SortColCmd("TYPE", true), false),
 		ui.KeyShiftR: ui.NewKeyAction("Sort Reason", e.GetTable().SortColCmd("REASON", true), false),
-		ui.KeyShiftE: ui.NewKeyAction("Sort Source", e.GetTable().SortColCmd("SOURCE", true), false),
+		ui.KeyShiftS: ui.NewKeyAction("Sort Source", e.GetTable().SortColCmd("SOURCE", true), false),
 		ui.KeyShiftC: ui.NewKeyAction("Sort Count", e.GetTable().SortColCmd("COUNT", true), false),
 	})
 }
